@@ -1,6 +1,6 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %  
-%  This file is part of Logtalk <http://logtalk.org/>    
+%  This file is part of Logtalk <https://logtalk.org/>    
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
 %  You may obtain a copy of the License at
@@ -72,7 +72,7 @@ mod_arc(5, 8).
 mod_member(Element, [Element| _]).
 mod_member(Element, [_| List]) :-
 	mod_member(Element, List).
-    
+
 mod_reverse(List, Reversed) :-
 	mod_reverse(List, [], Reversed, Reversed).
 
